meeg\_utils.preprocessing
=========================

.. automodule:: meeg_utils.preprocessing


.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   bad_channels
   batch
   ica
   line_noise
   pipeline
